@@ -30,7 +30,7 @@
 #*/###########################################################################
 setMethodS3("getMethodS3", "default", function(name, class="default", envir=parent.frame(), ...) {
   args <- list(name, class=class, optional=FALSE);
-  do.call("getS3method", args, envir=envir);
+  do.call(getS3method, args, envir=envir);
 })
 
 
